@@ -810,6 +810,16 @@ get_activation_action (NautilusFile *file)
 	return action;
 }
 
+gboolean
+nautilus_mime_file_launches (NautilusFile *file)
+{
+	ActivationAction activation_action;
+
+	activation_action = get_activation_action (file);
+
+	return (activation_action == ACTIVATION_ACTION_LAUNCH);
+}
+
 gboolean
 nautilus_mime_file_opens_in_external_app (NautilusFile *file)
 {
@@ -1923,7 +1933,7 @@ activation_mount_not_mounted (ActivateParameters *parameters)
 	files = get_file_list_for_launch_locations (parameters->locations);
 	nautilus_file_list_call_when_ready
 		(files,
-		 nautilus_mime_actions_get_required_file_attributes () | NAUTILUS_FILE_ATTRIBUTE_LINK_INFO,
+		 nautilus_mime_actions_get_required_file_attributes (),
 		 &parameters->files_handle,
 		 activate_callback, parameters);
 	nautilus_file_list_free (files);
@@ -2046,7 +2056,7 @@ activate_activation_uris_ready_callback (GList *files_ignore,
 	files = get_file_list_for_launch_locations (parameters->locations);
 	nautilus_file_list_call_when_ready
 		(files,
-		 nautilus_mime_actions_get_required_file_attributes () | NAUTILUS_FILE_ATTRIBUTE_LINK_INFO,
+		 nautilus_mime_actions_get_required_file_attributes (),
 		 &parameters->files_handle,
 		 activate_callback, parameters);
 	nautilus_file_list_free (files);
@@ -2069,13 +2079,6 @@ activation_get_activation_uris (ActivateParameters *parameters)
 			parameters->locations = g_list_delete_link (parameters->locations, l);
 			continue;
 		}
-		
-		if (nautilus_file_is_symbolic_link (file)) {
-			nautilus_file_invalidate_attributes 
-				(file,
-				 NAUTILUS_FILE_ATTRIBUTE_INFO |
-				 NAUTILUS_FILE_ATTRIBUTE_LINK_INFO);
-		}
 	}
 
 	if (parameters->locations == NULL) {
@@ -2085,9 +2088,7 @@ activation_get_activation_uris (ActivateParameters *parameters)
 
 	files = get_file_list_for_launch_locations (parameters->locations);
 	nautilus_file_list_call_when_ready
-		(files,
-		 NAUTILUS_FILE_ATTRIBUTE_INFO |
-		 NAUTILUS_FILE_ATTRIBUTE_LINK_INFO,
+		(files, nautilus_mime_actions_get_required_file_attributes (),
 		 &parameters->files_handle,
 		 activate_activation_uris_ready_callback, parameters);
 	nautilus_file_list_free (files);
