@@ -47,8 +47,6 @@ typedef struct {
 	GtkWidget *combo;
 
 	GtkWidget *type_widget;
-	
-	void *data;
 } NautilusQueryEditorRow;
 
 
@@ -57,7 +55,6 @@ typedef struct {
 	GtkWidget * (*create_widgets)      (NautilusQueryEditorRow *row);
 	void        (*add_to_query)        (NautilusQueryEditorRow *row,
 					    NautilusQuery          *query);
-	void        (*free_data)           (NautilusQueryEditorRow *row);
 	void        (*add_rows_from_query) (NautilusQueryEditor *editor,
 					    NautilusQuery *query);
 } NautilusQueryEditorRowOps;
@@ -66,15 +63,15 @@ struct NautilusQueryEditorDetails {
 	GtkWidget *entry;
 	gboolean change_frozen;
 	guint typing_timeout_id;
-	gboolean is_visible;
 
 	GtkWidget *search_current_button;
 	GtkWidget *search_all_button;
 	char *current_uri;
 
 	GList *rows;
-	char *last_set_query_text;
 	gboolean got_preedit;
+
+	NautilusQuery *query;
 };
 
 enum {
@@ -97,7 +94,6 @@ static NautilusQueryEditorRow * nautilus_query_editor_add_row (NautilusQueryEdit
 static GtkWidget *type_row_create_widgets      (NautilusQueryEditorRow *row);
 static void       type_row_add_to_query        (NautilusQueryEditorRow *row,
 					        NautilusQuery          *query);
-static void       type_row_free_data           (NautilusQueryEditorRow *row);
 static void       type_add_rows_from_query     (NautilusQueryEditor    *editor,
 					        NautilusQuery          *query);
 
@@ -107,7 +103,6 @@ static NautilusQueryEditorRowOps row_type[] = {
 	{ N_("File Type"),
 	  type_row_create_widgets,
 	  type_row_add_to_query,
-	  type_row_free_data,
 	  type_add_rows_from_query
 	},
 };
@@ -242,6 +237,13 @@ nautilus_query_editor_handle_event (NautilusQueryEditor *editor,
 	return handled;
 }
 
+static void
+row_destroy (NautilusQueryEditorRow *row)
+{
+	gtk_widget_destroy (row->toolbar);
+	g_free (row);
+}
+
 static void
 nautilus_query_editor_dispose (GObject *object)
 {
@@ -254,6 +256,11 @@ nautilus_query_editor_dispose (GObject *object)
 		editor->details->typing_timeout_id = 0;
 	}
 
+	g_clear_object (&editor->details->query);
+
+	g_list_free_full (editor->details->rows, (GDestroyNotify) row_destroy);
+	editor->details->rows = NULL;
+
 	G_OBJECT_CLASS (nautilus_query_editor_parent_class)->dispose (object);
 }
 
@@ -721,11 +728,6 @@ type_row_add_to_query (NautilusQueryEditorRow *row,
 	}
 }
 
-static void
-type_row_free_data (NautilusQueryEditorRow *row)
-{
-}
-
 static gboolean
 all_group_types_in_list (char **group_types, GList *mime_types)
 {
@@ -869,12 +871,8 @@ remove_row_cb (GtkButton *clicked_button, NautilusQueryEditorRow *row)
 	NautilusQueryEditor *editor;
 
 	editor = row->editor;
-	gtk_container_remove (GTK_CONTAINER (editor), row->toolbar);
-	
 	editor->details->rows = g_list_remove (editor->details->rows, row);
-
-	row_type[row->type].free_data (row);
-	g_free (row);
+	row_destroy (row);
 
 	nautilus_query_editor_changed (editor);
 }
@@ -901,9 +899,6 @@ row_type_combo_changed_cb (GtkComboBox *combo_box, NautilusQueryEditorRow *row)
 		row->type_widget = NULL;
 	}
 
-	row_type[row->type].free_data (row);
-	row->data = NULL;
-
 	row->type = type;
 	
 	create_type_widgets (row);
@@ -1159,6 +1154,7 @@ static void
 update_location (NautilusQueryEditor *editor)
 {
 	NautilusFile *file;
+	GtkWidget *label;
 
 	file = nautilus_file_get_by_uri (editor->details->current_uri);
 
@@ -1167,15 +1163,16 @@ update_location (NautilusQueryEditor *editor)
 		if (nautilus_file_is_home (file)) {
 			name = g_strdup (_("Home"));
 		} else {
-			char *filename;
-			filename = nautilus_file_get_display_name (file);
-			name = g_strdup_printf ("\342\200\234%s\342\200\235", filename);
-			g_free (filename);
+			name = nautilus_file_get_display_name (file);
 		}
-		gtk_button_set_label (GTK_BUTTON (editor->details->search_current_button),
-				      name);
+
+		gtk_button_set_label (GTK_BUTTON (editor->details->search_current_button), name);
 		g_free (name);
 
+		label = gtk_bin_get_child (GTK_BIN (editor->details->search_current_button));
+		gtk_label_set_ellipsize (GTK_LABEL (label), PANGO_ELLIPSIZE_MIDDLE);
+		g_object_set (label, "max-width-chars", 30, NULL);
+
 		nautilus_file_unref (file);
 	}
 }
@@ -1189,11 +1186,29 @@ nautilus_query_editor_set_location (NautilusQueryEditor *editor,
 	update_location (editor);
 }
 
+static void
+update_rows (NautilusQueryEditor *editor,
+	     NautilusQuery       *query)
+{
+	NautilusQueryEditorRowType type;
+
+	/* if we were just created, set the rows from query,
+	 * otherwise, re-use the query setting we have already.
+	 */
+	if (query != NULL && editor->details->query == NULL) {
+		for (type = 0; type < NAUTILUS_QUERY_EDITOR_ROW_LAST; type++) {
+			row_type[type].add_rows_from_query (editor, query);
+		}
+	} else if (query == NULL && editor->details->query != NULL) {
+		g_list_free_full (editor->details->rows, (GDestroyNotify) row_destroy);
+		editor->details->rows = NULL;
+	}
+}
+
 void
 nautilus_query_editor_set_query (NautilusQueryEditor	*editor,
 				 NautilusQuery		*query)
 {
-	NautilusQueryEditorRowType type;
 	char *text = NULL;
 
 	if (query != NULL) {
@@ -1210,18 +1225,14 @@ nautilus_query_editor_set_query (NautilusQueryEditor	*editor,
 	g_free (editor->details->current_uri);
 	editor->details->current_uri = NULL;
 
+	update_rows (editor, query);
+	g_clear_object (&editor->details->query);
+
 	if (query != NULL) {
+		editor->details->query = g_object_ref (query);
 		editor->details->current_uri = nautilus_query_get_location (query);
 		update_location (editor);
-
-
-		for (type = 0; type < NAUTILUS_QUERY_EDITOR_ROW_LAST; type++) {
-			row_type[type].add_rows_from_query (editor, query);
-		}
 	}
 
-	g_free (editor->details->last_set_query_text);
-	editor->details->last_set_query_text = text;
-
 	editor->details->change_frozen = FALSE;
 }
