@@ -101,6 +101,7 @@ struct NautilusWindowSlotDetails {
 	gulong qe_changed_id;
 	gulong qe_cancel_id;
 	gulong qe_activated_id;
+	gboolean search_visible;
 
         /* Load state */
 	GCancellable *find_mount_cancellable;
@@ -120,6 +121,7 @@ struct NautilusWindowSlotDetails {
 	guint location_change_distance;
 	char *pending_scroll_to;
 	GList *pending_selection;
+	gboolean pending_use_default_location;
 	NautilusFile *determine_view_file;
 	GCancellable *mount_cancellable;
 	GError *mount_error;
@@ -135,19 +137,6 @@ static void nautilus_window_slot_force_reload (NautilusWindowSlot *slot);
 static void location_has_really_changed (NautilusWindowSlot *slot);
 static void nautilus_window_slot_connect_new_content_view (NautilusWindowSlot *slot);
 
-static void
-toggle_toolbar_search_button (NautilusWindowSlot *slot,
-			      gboolean            active)
-{
-	GtkActionGroup *action_group;
-	GtkAction *action;
-
-	action_group = nautilus_window_get_main_action_group (slot->details->window);
-	action = gtk_action_group_get_action (action_group, NAUTILUS_ACTION_SEARCH);
-
-	gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action), active);
-}
-
 static void
 nautilus_window_slot_sync_search_widgets (NautilusWindowSlot *slot)
 {
@@ -158,19 +147,16 @@ nautilus_window_slot_sync_search_widgets (NautilusWindowSlot *slot)
 		return;
 	}
 
-	toggle = FALSE;
+	toggle = slot->details->search_visible;
 
-	if (slot->details->load_with_search) {
-		toggle = TRUE;
-	} else if (slot->details->content_view != NULL) {
+	if (slot->details->content_view != NULL) {
 		directory = nautilus_view_get_model (slot->details->content_view);
-		if (NAUTILUS_IS_SEARCH_DIRECTORY (directory) ||
-		    gtk_widget_get_visible (GTK_WIDGET (slot->details->query_editor))) {
+		if (NAUTILUS_IS_SEARCH_DIRECTORY (directory)) {
 			toggle = TRUE;
 		}
 	}
 
-	toggle_toolbar_search_button (slot, toggle);
+	nautilus_window_slot_set_search_visible (slot, toggle);
 }
 
 static gboolean
@@ -229,8 +215,9 @@ sync_search_directory (NautilusWindowSlot *slot)
 	text = nautilus_query_get_text (query);
 
 	if (!strlen (text)) {
-		location = nautilus_query_editor_get_location (slot->details->query_editor);
+		/* Prevent the location change from hiding the query editor in this case */
 		slot->details->load_with_search = TRUE;
+		location = nautilus_query_editor_get_location (slot->details->query_editor);
 		nautilus_window_slot_open_location (slot, location, 0);
 		g_object_unref (location);
 	} else {
@@ -273,7 +260,7 @@ static void
 query_editor_cancel_callback (NautilusQueryEditor *editor,
 			      NautilusWindowSlot *slot)
 {
-	toggle_toolbar_search_button (slot, FALSE);
+	nautilus_window_slot_set_search_visible (slot, FALSE);
 }
 
 static void
@@ -337,16 +324,10 @@ show_query_editor (NautilusWindowSlot *slot)
 	NautilusSearchDirectory *search_directory;
 	GFile *location;
 
-	/* This might be called while we're still loading the location.
-	 * In such a case, just set slot->details->load_with_search to TRUE, to stop
-	 * sync_search_widgets() from hiding it again when loading has
-	 * completed.
-	 */
 	if (slot->details->location) {
 		location = slot->details->location;
 	} else {
 		location = slot->details->pending_location;
-		slot->details->load_with_search = TRUE;
 	}
 
 	directory = nautilus_directory_get (location);
@@ -387,14 +368,62 @@ show_query_editor (NautilusWindowSlot *slot)
 }
 
 void
-nautilus_window_slot_set_query_editor_visible (NautilusWindowSlot *slot,
-					       gboolean            visible)
+nautilus_window_slot_set_search_visible (NautilusWindowSlot *slot,
+					 gboolean            visible)
 {
+	GtkActionGroup *action_group;
+	GtkAction *action;
+	gboolean old_visible;
+	GFile *return_location;
+	gboolean active_slot;
+
+	/* set search active state for the slot */
+	old_visible = slot->details->search_visible;
+	slot->details->search_visible = visible;
+
+	return_location = NULL;
+	active_slot = (slot == nautilus_window_get_active_slot (slot->details->window));
+
 	if (visible) {
 		show_query_editor (slot);
 	} else {
+		/* If search was active on this slot and became inactive, change
+		 * the slot location to the real directory.
+		 */
+		if (old_visible && active_slot) {
+			/* Use the query editor search root if possible */
+			return_location = nautilus_window_slot_get_query_editor_location (slot);
+
+			/* Use the home directory as a fallback */
+			if (return_location == NULL) {
+				return_location = g_file_new_for_path (g_get_home_dir ());
+			}
+		}
+
+		if (active_slot) {
+			nautilus_window_grab_focus (slot->details->window);
+		}
+
+		/* Now hide the editor and clear its state */
 		hide_query_editor (slot);
 	}
+
+	if (!active_slot) {
+		return;
+	}
+
+	/* also synchronize the window action state */
+	action_group = nautilus_window_get_main_action_group (slot->details->window);
+	action = gtk_action_group_get_action (action_group, NAUTILUS_ACTION_SEARCH);
+	gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action), visible);
+
+	/* If search was active on this slot and became inactive, change
+	 * the slot location to the real directory.
+	 */
+	if (return_location != NULL) {
+		nautilus_window_slot_open_location (slot, return_location, 0);
+		g_object_unref (return_location);
+	}
 }
 
 GFile *
@@ -417,7 +446,7 @@ nautilus_window_slot_handle_event (NautilusWindowSlot *slot,
 	}
 
 	if (retval) {
-		toggle_toolbar_search_button (slot, TRUE);
+		nautilus_window_slot_set_search_visible (slot, TRUE);
 	}
 
 	return retval;
@@ -768,12 +797,13 @@ nautilus_window_slot_open_location_full (NautilusWindowSlot *slot,
 	    !is_desktop) {
 
 		if (callback != NULL) {
-			callback (window, NULL, user_data);
+			callback (window, location, NULL, user_data);
 		}
 
 		goto done;
         }
 
+	slot->details->pending_use_default_location = ((flags & NAUTILUS_WINDOW_OPEN_FLAG_USE_DEFAULT_LOCATION) != 0);
         begin_location_change (target_slot, location, old_location, new_selection,
 			       NAUTILUS_LOCATION_CHANGE_STANDARD, 0, NULL, callback, user_data);
 
@@ -788,6 +818,7 @@ report_callback (NautilusWindowSlot *slot,
 	if (slot->details->open_callback != NULL) {
 		gboolean res;
 		res = slot->details->open_callback (nautilus_window_slot_get_window (slot),
+						    slot->details->pending_location,
 						    error, slot->details->open_callback_user_data);
 		slot->details->open_callback = NULL;
 		slot->details->open_callback_user_data = NULL;
@@ -972,39 +1003,36 @@ viewed_file_changed_callback (NautilusFile *file,
 
 	if (nautilus_file_is_gone (file) || (is_in_trash && !was_in_trash)) {
                 if (slot->details->viewed_file_seen) {
-			/* auto-show existing parent. */
 			GFile *go_to_file;
 			GFile *parent;
 			GFile *location;
 			GMount *mount;
 
-                        /* Detecting a file is gone may happen in the
-                         * middle of a pending location change, we
-                         * need to cancel it before closing the window
-                         * or things break.
-                         */
-			go_to_file = NULL;
 			parent = NULL;
-
 			location = nautilus_file_get_location (file);
-			mount = nautilus_get_mounted_mount_for_root (location);
-			if (mount != NULL) {
-				parent = g_file_get_parent (location);
-				g_object_unref (mount);
+
+			if (g_file_is_native (location)) {
+				mount = nautilus_get_mounted_mount_for_root (location);
+
+				if (mount == NULL) {
+					parent = g_file_get_parent (location);
+				}
+
+				g_clear_object (&mount);
 			}
-			g_object_unref (location);
 
 			if (parent != NULL) {
+				/* auto-show existing parent */
 				go_to_file = nautilus_find_existing_uri_in_hierarchy (parent);
-				g_object_unref (parent);
+			} else {
+				go_to_file = g_file_new_for_path (g_get_home_dir ());
 			}
 
-			if (go_to_file != NULL) {
-				nautilus_window_slot_open_location (slot, go_to_file, 0);
-				g_object_unref (go_to_file);
-			} else {
-				nautilus_window_slot_go_home (slot, FALSE);
-			}
+			nautilus_window_slot_open_location (slot, go_to_file, 0);
+
+			g_clear_object (&parent);
+			g_object_unref (go_to_file);
+			g_object_unref (location);
                 }
 	} else {
                 new_location = nautilus_file_get_location (file);
@@ -1086,7 +1114,8 @@ mount_not_mounted_callback (GObject *source_object,
 	} else {
 		nautilus_file_invalidate_all_attributes (slot->details->determine_view_file);
 		nautilus_file_call_when_ready (slot->details->determine_view_file,
-					       NAUTILUS_FILE_ATTRIBUTE_INFO,
+					       NAUTILUS_FILE_ATTRIBUTE_INFO |
+					       NAUTILUS_FILE_ATTRIBUTE_MOUNT,
 					       got_file_info_for_view_selection_callback,
 					       slot);
 	}
@@ -1104,10 +1133,11 @@ got_file_info_for_view_selection_callback (NautilusFile *file,
 	NautilusWindow *window;
 	NautilusWindowSlot *slot;
 	NautilusFile *viewed_file, *parent_file;
-	GFile *location;
+	GFile *location, *default_location;
 	GMountOperation *mount_op;
 	MountNotMountedData *data;
 	GtkApplication *app;
+	GMount *mount;
 
 	slot = callback_data;
 	window = nautilus_window_slot_get_window (slot);
@@ -1142,6 +1172,35 @@ got_file_info_for_view_selection_callback (NautilusFile *file,
 		goto done;
 	}
 
+	mount = NULL;
+	default_location = NULL;
+
+	if (slot->details->pending_use_default_location) {
+		mount = nautilus_file_get_mount (file);
+		slot->details->pending_use_default_location = FALSE;
+	}
+
+	if (mount != NULL) {
+		default_location = g_mount_get_default_location (mount);
+		g_object_unref (mount);
+	}
+
+	if (default_location != NULL &&
+	    !g_file_equal (slot->details->pending_location, default_location)) {
+		g_clear_object (&slot->details->pending_location);
+		slot->details->pending_location = default_location;
+		slot->details->determine_view_file = nautilus_file_get (default_location);
+
+		nautilus_file_invalidate_all_attributes (slot->details->determine_view_file);
+		nautilus_file_call_when_ready (slot->details->determine_view_file,
+					       NAUTILUS_FILE_ATTRIBUTE_INFO |
+					       NAUTILUS_FILE_ATTRIBUTE_MOUNT,
+					       got_file_info_for_view_selection_callback,
+					       slot);
+
+		goto done;
+	}
+
 	parent_file = nautilus_file_get_parent (file);
 	if ((parent_file != NULL) &&
 	    nautilus_file_get_file_type (file) == G_FILE_TYPE_REGULAR) {
@@ -1159,7 +1218,8 @@ got_file_info_for_view_selection_callback (NautilusFile *file,
 
 		nautilus_file_invalidate_all_attributes (slot->details->determine_view_file);
 		nautilus_file_call_when_ready (slot->details->determine_view_file,
-					       NAUTILUS_FILE_ATTRIBUTE_INFO,
+					       NAUTILUS_FILE_ATTRIBUTE_INFO |
+					       NAUTILUS_FILE_ATTRIBUTE_MOUNT,
 					       got_file_info_for_view_selection_callback,
 					       slot);
 
@@ -1343,9 +1403,20 @@ create_content_view (NautilusWindowSlot *slot,
 	}
 
 	if (NAUTILUS_IS_SEARCH_DIRECTORY (old_directory) &&
-	    !NAUTILUS_IS_SEARCH_DIRECTORY (new_directory) &&
-	    slot->details->pending_selection == NULL) {
-		slot->details->pending_selection = nautilus_view_get_selection (slot->details->content_view);
+	    !NAUTILUS_IS_SEARCH_DIRECTORY (new_directory)) {
+		/* Reset the search_active state when going out of a search directory,
+		 * before nautilus_window_slot_sync_search_widgets() is called
+		 * if we're not being loaded with search visible.
+		 */
+		if (!slot->details->load_with_search) {
+			slot->details->search_visible = FALSE;
+		}
+
+		slot->details->load_with_search = FALSE;
+
+		if (slot->details->pending_selection == NULL) {
+			slot->details->pending_selection = nautilus_view_get_selection (slot->details->content_view);
+		}
 	}
 
 	/* Actually load the pending location and selection: */
