@@ -25,10 +25,15 @@
 #ifndef NAUTILUS_WINDOW_SLOT_H
 #define NAUTILUS_WINDOW_SLOT_H
 
-#include "nautilus-view.h"
-#include "nautilus-window-types.h"
 #include "nautilus-query-editor.h"
 
+typedef struct NautilusWindowSlot NautilusWindowSlot;
+typedef struct NautilusWindowSlotClass NautilusWindowSlotClass;
+typedef struct NautilusWindowSlotDetails NautilusWindowSlotDetails;
+
+#include "nautilus-view.h"
+#include "nautilus-window.h"
+
 #define NAUTILUS_TYPE_WINDOW_SLOT	 (nautilus_window_slot_get_type())
 #define NAUTILUS_WINDOW_SLOT_CLASS(k)     (G_TYPE_CHECK_CLASS_CAST((k), NAUTILUS_TYPE_WINDOW_SLOT, NautilusWindowSlotClass))
 #define NAUTILUS_WINDOW_SLOT(obj)	 (G_TYPE_CHECK_INSTANCE_CAST ((obj), NAUTILUS_TYPE_WINDOW_SLOT, NautilusWindowSlot))
@@ -51,8 +56,6 @@ struct NautilusWindowSlotClass {
 	void (* inactive) (NautilusWindowSlot *slot);
 };
 
-typedef struct NautilusWindowSlotDetails NautilusWindowSlotDetails;
-
 /* Each NautilusWindowSlot corresponds to a location in the window
  * for displaying a NautilusView, i.e. a tab.
  */
@@ -94,9 +97,9 @@ char *         nautilus_window_slot_get_current_uri        (NautilusWindowSlot *
 GList * nautilus_window_slot_get_back_history              (NautilusWindowSlot *slot);
 GList * nautilus_window_slot_get_forward_history           (NautilusWindowSlot *slot);
 
-void    nautilus_window_slot_set_query_editor_visible	   (NautilusWindowSlot *slot,
-							    gboolean            visible);
 GFile * nautilus_window_slot_get_query_editor_location     (NautilusWindowSlot *slot);
+void    nautilus_window_slot_set_search_visible            (NautilusWindowSlot *slot,
+							    gboolean            visible);
 
 gboolean nautilus_window_slot_get_allow_stop               (NautilusWindowSlot *slot);
 void     nautilus_window_slot_set_allow_stop		   (NautilusWindowSlot *slot,
